@@ -14,48 +14,8 @@ import java.util.HashMap;
 import java.util.Map;
 
 import org.gnu.glib.EventType;
-import org.gnu.gnome.event.AppBarListener;
-import org.gnu.gnome.event.ClientListener;
-import org.gnu.gnome.event.ColorPickerListener;
-import org.gnu.gnome.event.DateEditListener;
-import org.gnu.gnome.event.DruidPageChangeListener;
-import org.gnu.gnome.event.DruidPageSetupListener;
-import org.gnu.gnome.event.FontPickerListener;
 import org.gnu.gtk.Widget;
-import org.gnu.gtk.event.AdjustmentListener;
-import org.gnu.gtk.event.ButtonListener;
-import org.gnu.gtk.event.CalendarListener;
-import org.gnu.gtk.event.CellRendererTextListener;
-import org.gnu.gtk.event.CheckMenuItemListener;
-import org.gnu.gtk.event.ColorButtonListener;
-import org.gnu.gtk.event.ComboBoxListener;
-import org.gnu.gtk.event.ContainerListener;
-import org.gnu.gtk.event.DialogListener;
-import org.gnu.gtk.event.EntryListener;
-import org.gnu.gtk.event.ExpanderListener;
-import org.gnu.gtk.event.ExposeListener;
-import org.gnu.gtk.event.FocusListener;
-import org.gnu.gtk.event.FontButtonListener;
 import org.gnu.gtk.event.GtkEvent;
-import org.gnu.gtk.event.ItemListener;
-import org.gnu.gtk.event.KeyListener;
-import org.gnu.gtk.event.LifeCycleListener;
-import org.gnu.gtk.event.MenuItemListener;
-import org.gnu.gtk.event.MouseListener;
-import org.gnu.gtk.event.MouseMotionListener;
-import org.gnu.gtk.event.NotebookListener;
-import org.gnu.gtk.event.OptionMenuListener;
-import org.gnu.gtk.event.RangeListener;
-import org.gnu.gtk.event.ScaleListener;
-import org.gnu.gtk.event.SpinListener;
-import org.gnu.gtk.event.TextBufferListener;
-import org.gnu.gtk.event.TextViewListener;
-import org.gnu.gtk.event.ToggleListener;
-import org.gnu.gtk.event.ToolBarListener;
-import org.gnu.gtk.event.ToolButtonListener;
-import org.gnu.gtk.event.TreeModelListener;
-import org.gnu.gtk.event.TreeSelectionListener;
-import org.gnu.gtk.event.TreeViewColumnListener;
 
 /**
  * ListenerDelegate: abstract base class for Java-GNOME event listener
@@ -183,7 +143,8 @@ abstract class ListenerDelegate {
         } catch (InvocationTargetException e) {
             throw e;
         } catch (Exception e) {
-            throw new InvocationTargetException(e, 
+        	e.printStackTrace();
+        	throw new InvocationTargetException(e, 
                                                 "ListenerDelegate - " +
                                                 "create failure!");
         }
@@ -196,6 +157,7 @@ abstract class ListenerDelegate {
         delegateMap.put("org.gnu.gtk.event.AdjustmentListener", "org.gnu.glade.AdjustmentDelegate");
         delegateMap.put("org.gnu.gtk.event.ButtonListener", "org.gnu.glade.ButtonDelegate");
         delegateMap.put("org.gnu.gtk.event.CalendarListener", "org.gnu.glade.CalendarDelegate");
+        delegateMap.put("org.gnu.gtk.event.CellEditableListener", "org.gnu.glade.CellEditableDelegate");
         delegateMap.put("org.gnu.gtk.event.CellRendererTextListener", "org.gnu.glade.CellRendererTextDelegate");
         delegateMap.put("org.gnu.gtk.event.CheckMenuItemListener", "org.gnu.glade.CheckMenuItemDelegate");
         delegateMap.put("org.gnu.gtk.event.ColorButtonListener", "org.gnu.glade.ColorButtonDelegate");
